@@ -5,28 +5,30 @@ import rx.operators as ops
 def first_mux():
     def _first(source):
         def on_subscribe(observer, scheduler):
-            state = []
+            state = None
 
             def on_next(i):
+                nonlocal state
+
                 if type(i) is rs.OnNextMux:
-                    if state[i.key[0]] is False:
+                    value = i.store.get_state(state, i.key)
+                    if value is False:
                         observer.on_next(i)
-                        state[i.key[0]] = True
+                        i.store.set_state(state, i.key, True)
+
                 elif type(i) is rs.OnCreateMux:
-                    append_count = (i.key[0]+1) - len(state)
-                    if append_count > 0:
-                        for _ in range(append_count):
-                            state.append(None)
-                    state[i.key[0]] = False
+                    i.store.add_key(state, i.key)
                     observer.on_next(i)
+
                 elif type(i) is rs.OnCompletedMux:
                     observer.on_next(i)
-                    state[i.key[0]] = None
-                elif type(i) is rs.OnErrorMux:
-                    observer.on_next(rs.OnErrorMux(i.key, i.error))
-                    state[i.key[0]] = None
+                    i.store.del_key(state, i.key)
+
+                elif type(i) is rs.state.ProbeStateTopology:
+                    state = i.topology.create_state(name='first', data_type=bool, default_value=False)
+                    observer.on_next(i)
                 else:
-                    observer.on_next(TypeError("first: unknow item type: {}".format(type(i))))
+                    observer.on_next(i)
 
             return source.subscribe(
                 on_next=on_next,
@@ -40,6 +42,21 @@ def first_mux():
 
 
 def first():
+    """Emits the first element of an observable
+
+    The source can be an Observable or a MuxObservable.
+
+    .. marble::
+        :alt: first
+
+        ---1---2---3---4----|
+        [      first()      ]
+        -------2-|
+
+    Returns:
+        An observable emitting the first item from the source
+        observable.
+    """
     def _first(source):
         if isinstance(source, rs.MuxObservable):
             return first_mux()(source)
