@@ -1,33 +1,39 @@
 import rxsci as rs
 import rx.operators as ops
-from rxsci.internal.utils import NotSet
 
 
 def last_mux():
     def _last(source):
         def on_subscribe(observer, scheduler):
-            state = []
+            state = None
 
             def on_next(i):
+                nonlocal state
+
                 if type(i) is rs.OnNextMux:
-                    state[i.key[0]] = i.item
+                    i.store.set_state(state, i.key, i.item)
+
                 elif type(i) is rs.OnCreateMux:
-                    append_count = (i.key[0]+1) - len(state)
-                    if append_count > 0:
-                        for _ in range(append_count):
-                            state.append(NotSet)
+                    i.store.add_key(state, i.key)
                     observer.on_next(i)
+
                 elif type(i) is rs.OnCompletedMux:
-                    value = state[i.key[0]]
-                    if value is not NotSet:
-                        observer.on_next(rs.OnNextMux(i.key, value))
+                    value = i.store.get_state(state, i.key)
+                    if value is not rs.state.markers.STATE_NOTSET:
+                        observer.on_next(rs.OnNextMux(i.key, value, i.store))
                     observer.on_next(i)
-                    state[i.key[0]] = NotSet
+                    i.store.del_key(state, i.key)
+
                 elif type(i) is rs.OnErrorMux:
-                    observer.on_next(rs.OnErrorMux(i.key, i.error))
-                    state[i.key[0]] = NotSet
+                    observer.on_next(i)
+                    i.store.del_key(state, i.key)
+
+                elif type(i) is rs.state.ProbeStateTopology:
+                    state = i.topology.create_state(name='last', data_type='obj')
+                    observer.on_next(i)
                 else:
-                    observer.on_next(TypeError("first: unknow item type: {}".format(type(i))))
+                    observer.on_next(i)
+
 
             return source.subscribe(
                 on_next=on_next,
@@ -41,6 +47,21 @@ def last_mux():
 
 
 def last():
+    """Emits the last element of an observable
+
+    The source can be an Observable or a MuxObservable.
+
+    .. marble::
+        :alt: last
+
+        ---1---2---3---4--|
+        [      last()       ]
+        ------------------4-|
+
+    Returns:
+        An observable emitting the last item from the source
+        observable.
+    """
     def _last(source):
         if isinstance(source, rs.MuxObservable):
             return last_mux()(source)
